@@ -51,15 +51,10 @@ GeomInteractiveText <- ggproto(
   required_aes = c("x", "y", "label"),
 
   default_aes = aes(
-    colour = "black",
-    size = 3.88,
-    angle = 0,
-    hjust = 0.5,
-    vjust = 0.5,
-    alpha = NA,
-    family = "",
-    fontface = 1,
-    lineheight = 1.2
+    colour = "black", size = 3.88, angle = 0,
+    hjust = 0.5, vjust = 0.5, alpha = NA,
+    family = "", fontface = 1, lineheight = 1.2,
+    tooltip = NULL, onclick = NULL, data_id = NULL
   ),
 
   draw_panel = function(data,
