@@ -3,10 +3,8 @@
 #' @import rvg
 #' @import grid
 #' @importFrom grDevices dev.off
-#' @importFrom xml2 read_xml
-#' @importFrom xml2 xml_find_all
-#' @importFrom xml2 xml_text
-#' @importFrom xml2 xml_ns
+#' @importFrom xml2 read_xml xml_find_all xml_text xml_ns
+#' @importFrom xml2 xml_remove xml_attr xml_attr<-
 
 #' @title ggiraph
 #'
@@ -26,7 +24,6 @@
 #' @param ggobj ggplot objet to print. argument \code{code} will
 #' be ignored if this argument is supplied.
 #' @param pointsize the default pointsize of plotted text in pixels, default to 12.
-#' @param width widget width ratio (0 < width <= 1)
 #' @param width_svg,height_svg svg viewbox width and height in inches
 #' @param tooltip_extra_css extra css (added to \code{position: absolute;pointer-events: none;})
 #' used to customize tooltip area.
@@ -38,14 +35,16 @@
 #' @param selection_type row selection mode ("single", "multiple", "none")
 #'  when widget is in a Shiny application.
 #' @param selected_css css to apply when element is selected (shiny only).
+#' @param width widget width ratio (0 < width <= 1)
+#' @param flexdashboard should be TRUE when used within a flexdashboard to
+#' ensure svg will fit in boxes.
 #' @param ... arguments passed on to \code{\link[rvg]{dsvg}}
 #' @examples
 #' # ggiraph simple example -------
 #' @example examples/geom_point_interactive.R
 #' @export
 ggiraph <- function(code, ggobj = NULL,
-	pointsize = 12,
-	width = 0.7,
+	pointsize = 12, width = 0.7,
 	width_svg = 6, height_svg = 6,
 	tooltip_extra_css,
 	hover_css,
@@ -54,7 +53,7 @@ ggiraph <- function(code, ggobj = NULL,
 	tooltip_offy = 0,
 	zoom_max = 1,
 	selection_type = "multiple",
-	selected_css,
+	selected_css, flexdashboard = FALSE,
 	...) {
 
   if( missing( tooltip_extra_css ))
@@ -73,14 +72,9 @@ ggiraph <- function(code, ggobj = NULL,
   stopifnot(tooltip_opacity > 0 && tooltip_opacity <= 1)
   stopifnot(tooltip_opacity > 0 && tooltip_opacity <= 1)
   stopifnot(is.numeric(zoom_max))
-  stopifnot(is.numeric(width))
-  stopifnot( 0 < width && width <= 1.0)
 
   if( zoom_max < 1 )
     stop("zoom_max should be >= 1")
-  if( zoom_max == 1 )
-    zoompan = FALSE
-  else zoompan = TRUE
 
 	ggiwid.options = getOption("ggiwid")
 	tmpdir = tempdir()
@@ -101,14 +95,14 @@ ggiraph <- function(code, ggobj = NULL,
 	ggiwid.options$svgid = 1 + ggiwid.options$svgid
 	options("ggiwid"=ggiwid.options)
 
-	svg_container <- paste( scan(path, what = "character", sep = "\n", quiet = TRUE), collapse = "")
 	data <- read_xml( path )
 	scr <- xml_find_all(data, "//*[@type='text/javascript']", ns = xml_ns(data) )
 	js <- paste( sapply( scr, xml_text ), collapse = ";")
 
-	unlink(path)
+	xml_remove(scr)
+  xml_attr(data, "width") <- NULL
+  xml_attr(data, "height") <- NULL
 
-	data_id_class <- paste0("cl_data_id_", ggiwid.options$svgid)
 
 	if( grepl(x = tooltip_extra_css, pattern = "position[ ]*:") )
 	  stop("please, do not specify position in tooltip_extra_css, this parameter is managed by ggiraph.")
@@ -116,31 +110,19 @@ ggiraph <- function(code, ggobj = NULL,
 	  stop("please, do not specify pointer-events in tooltip_extra_css, this parameter is managed by ggiraph.")
 
 
-	padding_bottom <- width * (height_svg / width_svg)
-	width <- sprintf("%.0f%%", width * 100 )
-	padding_bottom <- sprintf("%.0f%%", padding_bottom * 100 )
-	x = list( html = HTML( svg_container ), code = js, canvas_id = ggiwid.options$svgid,
-	          data_id_class = data_id_class,
-	          tooltip_extra_css = tooltip_extra_css,
-	          hover_css = hover_css,
-	          tooltip_opacity = tooltip_opacity,
-	          tooltip_offx = tooltip_offx,
-	          tooltip_offy = tooltip_offy,
+	x = list( html = HTML( as.character(data) ), code = js,
+	          tooltip_extra_css = tooltip_extra_css, hover_css = hover_css, selected_css = selected_css,
+	          tooltip_opacity = tooltip_opacity, tooltip_offx = tooltip_offx, tooltip_offy = tooltip_offy,
 	          zoom_max = zoom_max,
-	          zoompan = zoompan,
 	          selection_type = selection_type,
-	          selected_css = selected_css,
-	          width = width,
-	          padding_bottom = padding_bottom
+	          ratio = width_svg / height_svg, flexdashboard = flexdashboard, width = width
 	          )
+	unlink(path)
+
 	# create widget
 	htmlwidgets::createWidget(
-			name = 'ggiraph',
-			x,
-			width = NULL,
-			height = NULL,
-			package = 'ggiraph',
-			sizingPolicy = sizingPolicy(knitr.figure = FALSE)
+			name = 'ggiraph', x = x, package = 'ggiraph',
+			sizingPolicy = sizingPolicy(knitr.figure = FALSE, defaultWidth = "70%", defaultHeight = "auto")
 	)
 }
 
@@ -165,10 +147,10 @@ ggiraph <- function(code, ggobj = NULL,
 ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
 
   msger <- sprintf(
-    "Shiny.addCustomMessageHandler('%s',function(message) {var varname = '%s';d3.selectAll(window['%s'] + ' *[data-id]').classed('selected_', false);d3.selectAll(message).each(function(d, i) {d3.selectAll(window['%s'] + ' *[data-id=\"'+ message[i] + '\"]').classed('selected_', true);});window[varname] = message;Shiny.onInputChange(varname, window[varname]);});",
+    "Shiny.addCustomMessageHandler('%s',function(message) {var varname = '%s';d3.selectAll('#%s *[data-id]').classed('selected_%s', false);d3.selectAll(message).each(function(d, i) {d3.selectAll('#%s *[data-id=\"'+ message[i] + '\"]').classed('selected_%s', true);});window[varname] = message;Shiny.onInputChange(varname, window[varname]);});",
     paste0(outputId, "_set"),
     paste0(outputId, "_selected"),
-    paste0(outputId, "_canvas"), paste0(outputId, "_canvas") )
+    outputId, outputId, outputId, outputId)
 
   div(
     singleton( tags$head(tags$script(msger)) ),
